@@ -1,11 +1,15 @@
-from typing import Dict
+from typing import Dict, List
 from decimal import Decimal
 
+from rest_framework.request import Request
+
 from polaris import settings
 from polaris.models import Asset
 
 
-def calculate_fee(fee_params: Dict) -> Decimal:
+def calculate_fee(
+    fee_params: Dict, *_args: List, request: Request = None, **_kwargs: Dict
+) -> Decimal:
     """
     .. _`/fee`: https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0024.md#fee
 
